@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011
+# Copyright © 2008-2015
 #   Piotr Lewandowski <piotr.lewandowski@gmail.com>,
 #   Jakub Wilk <jwilk@jwilk.net>.
 #
@@ -13,8 +13,10 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 
+from __future__ import print_function
+
 def debug(*args, **kwargs):
-    print 'debug(*%r, **%r)' % (args, kwargs)
+    print('debug(*%r, **%r)' % (args, kwargs))
 
 def strip_headers(headers='To,Cc,Bcc', message=None):
     headers = headers.split(',')
@@ -27,4 +29,10 @@ def mimify(type='text/plain', charset='US-ASCII', message=None):
         message['Content-Type'] = '%(type)s; charset=%(charset)s' % locals()
     return message
 
-# vim:ts=4 sw=4 et
+__all__ = [
+    'debug',
+    'mimify',
+    'strip_headers',
+]
+
+# vim:ts=4 sts=4 sw=4 et
