@@ -1,7 +1,6 @@
-#!/usr/bin/python
 # encoding=UTF-8
 
-# Copyright © 2011, 2012
+# Copyright © 2011-2016
 #   Jakub Wilk <jwilk@jwilk.net>.
 #
 # This program is free software; you can redistribute it and/or modify it
@@ -20,6 +19,13 @@ except ImportError:
 
 import os
 
+try:
+    # Python 3.4+
+    from importlib import reload
+except ImportError:
+    # Python 3.3 or older
+    from imp import reload
+
 import utils
 
 class test_split_host(unittest.TestCase):
@@ -82,8 +88,7 @@ class test_xdg(unittest.TestCase):
         )
 
     def test_XDG_DATA_HOME_unset(self):
-        os.environ['XDG_DATA_HOME'] = ''
-        del os.environ['XDG_DATA_HOME']
+        os.environ.pop('XDG_DATA_HOME', None)
         self._check_xdg_data_home()
 
     def test_XDG_DATA_HOME_empty(self):
@@ -98,7 +103,24 @@ class test_xdg(unittest.TestCase):
         os.environ['XDG_DATA_HOME'] = '/eggs'
         self._check_xdg_data_home('/eggs')
 
+class test_join_lines(unittest.TestCase):
+
+    def test_empty(self):
+        lst = []
+        s = utils.join_lines(lst)
+        self.assertEqual(s, b'\n')
+
+    def test_trailing_lf(self):
+        lst = [b'eggs', b'bacon', b'spam']
+        s = utils.join_lines(lst)
+        self.assertEqual(s, b'eggs\nbacon\nspam\n')
+
+    def test_no_trailing_lf(self):
+        lst = [b'eggs', b'bacon', b'spam\n']
+        s = utils.join_lines(lst)
+        self.assertEqual(s, b'eggs\nbacon\nspam\n')
+
 if __name__ == '__main__':
     unittest.main()
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
